@@ -252,6 +252,14 @@ func Test_addRoute(t *testing.T) {
 				"http://localhost/foo?bar=baz":         http.StatusNotFound,
 			},
 		},
+		{
+			desc: "Query with multiple equals",
+			rule: "Query(`foo=b=ar`)",
+			expected: map[string]int{
+				"http://localhost/foo?foo=b=ar": http.StatusOK,
+				"http://localhost/foo?foo=bar":  http.StatusNotFound,
+			},
+		},
 		{
 			desc: "Rule with simple path",
 			rule: `Path("/a")`,
